==> istio-model-v1alpha3-5.12.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ServiceEntrySpecBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ServiceEntrySpecBuilder extends io.fabric8.istio.api.networking.v1alpha3.ServiceEntrySpecFluentImpl<io.fabric8.istio.api.networking.v1alpha3.ServiceEntrySpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.istio.api.networking.v1alpha3.ServiceEntrySpec,io.fabric8.istio.api.networking.v1alpha3.ServiceEntrySpecBuilder>{
  public ServiceEntrySpecBuilder() {
    this(false);
  }
  public ServiceEntrySpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ServiceEntrySpec(), validationEnabled);
  }
  public ServiceEntrySpecBuilder(io.fabric8.istio.api.networking.v1alpha3.ServiceEntrySpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceEntrySpecBuilder(io.fabric8.istio.api.networking.v1alpha3.ServiceEntrySpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ServiceEntrySpec(), validationEnabled);
  }
  public ServiceEntrySpecBuilder(io.fabric8.istio.api.networking.v1alpha3.ServiceEntrySpecFluent<?> fluent,io.fabric8.istio.api.networking.v1alpha3.ServiceEntrySpec instance) {
    this(fluent, instance, false);
  }
  public ServiceEntrySpecBuilder(io.fabric8.istio.api.networking.v1alpha3.ServiceEntrySpecFluent<?> fluent,io.fabric8.istio.api.networking.v1alpha3.ServiceEntrySpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAddresses(instance.getAddresses()); 
    fluent.withEndpoints(instance.getEndpoints()); 
    fluent.withExportTo(instance.getExportTo()); 
    fluent.withHosts(instance.getHosts()); 
    fluent.withLocation(instance.getLocation()); 
    fluent.withPorts(instance.getPorts()); 
    fluent.withResolution(instance.getResolution()); 
    fluent.withSubjectAltNames(instance.getSubjectAltNames()); 
    fluent.withWorkloadSelector(instance.getWorkloadSelector()); 
    this.validationEnabled = validationEnabled; 
  }
  public ServiceEntrySpecBuilder(io.fabric8.istio.api.networking.v1alpha3.ServiceEntrySpec instance) {
    this(instance,false);
  }
  public ServiceEntrySpecBuilder(io.fabric8.istio.api.networking.v1alpha3.ServiceEntrySpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAddresses(instance.getAddresses()); 
    this.withEndpoints(instance.getEndpoints()); 
    this.withExportTo(instance.getExportTo()); 
    this.withHosts(instance.getHosts()); 
    this.withLocation(instance.getLocation()); 
    this.withPorts(instance.getPorts()); 
    this.withResolution(instance.getResolution()); 
    this.withSubjectAltNames(instance.getSubjectAltNames()); 
    this.withWorkloadSelector(instance.getWorkloadSelector()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.istio.api.networking.v1alpha3.ServiceEntrySpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.istio.api.networking.v1alpha3.ServiceEntrySpec build() {
    ServiceEntrySpec buildable = new ServiceEntrySpec(fluent.getAddresses(),fluent.getEndpoints(),fluent.getExportTo(),fluent.getHosts(),fluent.getLocation(),fluent.getPorts(),fluent.getResolution(),fluent.getSubjectAltNames(),fluent.getWorkloadSelector());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ServiceEntrySpecBuilder that = (ServiceEntrySpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> istio-model-v1alpha3-6.1.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ServiceEntrySpecBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ServiceEntrySpecBuilder extends ServiceEntrySpecFluentImpl<ServiceEntrySpecBuilder> implements VisitableBuilder<ServiceEntrySpec,ServiceEntrySpecBuilder>{
  public ServiceEntrySpecBuilder() {
    this(false);
  }
  public ServiceEntrySpecBuilder(Boolean validationEnabled) {
    this(new ServiceEntrySpec(), validationEnabled);
  }
  public ServiceEntrySpecBuilder(ServiceEntrySpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceEntrySpecBuilder(ServiceEntrySpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ServiceEntrySpec(), validationEnabled);
  }
  public ServiceEntrySpecBuilder(ServiceEntrySpecFluent<?> fluent,ServiceEntrySpec instance) {
    this(fluent, instance, false);
  }
  public ServiceEntrySpecBuilder(ServiceEntrySpecFluent<?> fluent,ServiceEntrySpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAddresses(instance.getAddresses()); 
    fluent.withEndpoints(instance.getEndpoints()); 
    fluent.withExportTo(instance.getExportTo()); 
    fluent.withHosts(instance.getHosts()); 
    fluent.withLocation(instance.getLocation()); 
    fluent.withPorts(instance.getPorts()); 
    fluent.withResolution(instance.getResolution()); 
    fluent.withSubjectAltNames(instance.getSubjectAltNames()); 
    fluent.withWorkloadSelector(instance.getWorkloadSelector()); 
    this.validationEnabled = validationEnabled; 
  }
  public ServiceEntrySpecBuilder(ServiceEntrySpec instance) {
    this(instance,false);
  }
  public ServiceEntrySpecBuilder(ServiceEntrySpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAddresses(instance.getAddresses()); 
    this.withEndpoints(instance.getEndpoints()); 
    this.withExportTo(instance.getExportTo()); 
    this.withHosts(instance.getHosts()); 
    this.withLocation(instance.getLocation()); 
    this.withPorts(instance.getPorts()); 
    this.withResolution(instance.getResolution()); 
    this.withSubjectAltNames(instance.getSubjectAltNames()); 
    this.withWorkloadSelector(instance.getWorkloadSelector()); 
    this.validationEnabled = validationEnabled; 
  }
  ServiceEntrySpecFluent<?> fluent;
  Boolean validationEnabled;
  public ServiceEntrySpec build() {
    ServiceEntrySpec buildable = new ServiceEntrySpec(fluent.getAddresses(),fluent.getEndpoints(),fluent.getExportTo(),fluent.getHosts(),fluent.getLocation(),fluent.getPorts(),fluent.getResolution(),fluent.getSubjectAltNames(),fluent.getWorkloadSelector());
    return buildable;
  }
  
}
